# -*- coding: utf-8 -*-
import os

VERSION = "2.6.0"
DESCRIPTION = """
Spider163的数据基础，来源于网易公司的网易云音乐产品。其授权协议，包含《网易云音乐服务条款》但不包含其霸王条款。
该项目遵循MIT开源协议。我们认为知识属于全人类，网易云音乐的评论区属于用户，不属于网易云音乐。
而广大网民有权利根据自己的喜好阅读、整理、分析和总结开放的、非私密信息。

您可以选择四种方式支持本项目的开发：
No.1 在Github上star本项目，或者在其它任何场合宣传本项目。
附：Spider163 GitHub 地址 https://github.com/Chengyumeng/spider163
No.2 关注本项目作者的唯一个人微信公众账号。
公众号名字：程天写代码
No.3 通过支付宝向作者转账赞助。
支付宝二维码：https://github.com/Chengyumeng/spider163/blob/master/spider163/www/static/img/zhifubao.jpeg
No.4 通过微信向作者转账赞助。
微信二维码：https://github.com/Chengyumeng/spider163/blob/master/spider163/www/static/img/weixin.jpeg
"""
root_path = os.path.dirname(os.path.abspath(__file__))
