<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <title>Welcome To Spider163</title>
    <link rel="stylesheet" href="/static/css/spider163.css">
    <link href="https://cdn.bootcss.com/bootstrap/3.3.7/css/bootstrap.min.css" rel="stylesheet">

    <link href="http://g.alicdn.com/sj/dpl/1.5.1/css/sui.min.css" rel="stylesheet">
</head>
<body>
<ul class="nav nav-tabs">
  <li role="presentation"><a href="/#">主页</a></li>
    <li role="presentation"><a href="/spider">抓取</a></li>
  <li role="presentation"><a href="/stat">统计</a></li>
    <li role="presentation"><a href="/scan">浏览</a></li>
    <li role="presentation"><a href="/bussiness">商业</a></li>
</ul>

<div class="page-header" style="padding-left:100px">
						<h2>Spider163 用户许可 和 我们的期待</h2>
</div>
<div>
    <p class="navbar-text">
        Spider163的数据基础，来源于网易公司的网易云音乐产品。其授权协议，包含《网易云音乐服务条款》但不包含其霸王条款。<br>
        该项目遵循MIT开源协议。我们认为知识属于全人类，网易云音乐的评论区属于用户，不属于网易云音乐。<br>
        而广大网民有权利根据自己的喜好阅读、整理、分析和总结开放的、非私密信息。<br>
        附：<a href="http://music.163.com/html/web2/service.html" target="_blank">《网易云音乐服务条款》</a><br>
        您可以选择四种方式支持本项目的开发：<br>
        No.1 在Github上star本项目，或者在其它任何场合宣传本项目。<br>
        附：<a href="https://github.com/Chengyumeng/spider163" target="_blank">Spider163 GitHub 地址</a><br>
        No.2 关注本项目作者的唯一个人微信公众账号。<br>
        公众号名字：程天写代码<br>
        No.3 通过支付宝向作者转账赞助。<br>
        <img src="/static/img/zhifubao.jpeg" width="180px"><br>
        No.4 通过微信向作者转账赞助。<br>
        <img src="/static/img/weixin.jpeg" width="180px"><br>
        自2018年起，所有的现金转账赞助的朋友都可以在通过转账留言在本页面留言（50字以内）<br>
     </p>
</div>
</body>
</html>